use std::process::Command;

#[allow(dead_code)]
const PARSE_FUNCTION_RAW: &str = include_str!("../powershell/get-metadata.ps1");

#[allow(dead_code)]
fn get_parse_function() -> String {
    format!("function parse_ps() {{{PARSE_FUNCTION_RAW}}}")
}

#[allow(dead_code)]
fn parse_powershell_file(path: &str) -> Result<serde_json::Value, String> {
    let func = get_parse_function();

    let ps_runner = format!("{func}; parse_ps -Path '{path}' | ConvertTo-Json -Depth 10");

    let output = Command::new("pwsh")
        .args(["-NoProfile", "-Command", &ps_runner])
        .output()
        .map_err(|e| e.to_string())?;
    if output.status.success() {
        let stdout_str = String::from_utf8_lossy(&output.stdout);
        Ok(serde_json::from_str(&stdout_str).map_err(|e| e.to_string())?)
    } else {
        Err(String::from("Failed to run PowerShell"))
    }
}

#[cfg(test)]
mod test {
    use super::*;

    #[test]
    fn test_parse_powershell_file() {
        let got = parse_powershell_file("powershell/test-script.ps1");
        assert!(got.is_ok());
    }
}
